// ✅ متغيرات الحالة
let isRunning = { "TeePublic": false, "Redbubble": false };
let totalDesigns = { "TeePublic": 0, "Redbubble": 0 };
let uploadQueue = { "TeePublic": [], "Redbubble": [] };
let hasSentMessage = {}; // ✅ منع إرسال البيانات مرتين

// ✅ استقبال أوامر بدء وإيقاف النشر
chrome.runtime.onMessage.addListener((request, sender, sendResponse) => {
    console.log(`📩 استلام رسالة من ${request.platform}:`, request);

    if (request.action === "startUploading") {
        console.log(`🚀 بدء رفع التصاميم على ${request.platform}`);
        startUploading(request.platform);
    } else if (request.action === "stopUploading") {
        console.log(`⏸️ تم إيقاف الرفع على ${request.platform}`);
        stopUploading(request.platform);
    } else if (request.action === "designPublished") {
        console.log(`✅ تم نشر تصميم: ${request.filename} على ${request.platform}, يتم الآن حذف البيانات.`);
        handleDesignPublished(request.platform, request.filename, sender.tab.id);
    }
    sendResponse({ status: "received" });
});


// ✅ إرسال حالة التشغيل عند طلب popup.js
chrome.runtime.onMessage.addListener((request, sender, sendResponse) => {
    if (request.action === "checkStatus") {
        sendResponse({ isRunning: isRunning[request.platform] });
    }
});


chrome.runtime.onMessage.addListener((request, sender, sendResponse) => {
    if (request.action === "tabClosed") {
        console.log(`🛑 تم إغلاق تبويب ${request.platform}, سيتم إيقاف أي عمليات نشطة.`);
        isRunning[request.platform] = false;
        chrome.storage.local.set({ [`isRunning_${request.platform}`]: false });
    }
});


// ✅ بدء عملية النشر
function startUploading(platform) {
    if (isRunning[platform]) return;
    isRunning[platform] = true;

    chrome.storage.local.set({ [`isRunning_${platform}`]: true }, () => {
        console.log(`🚀 تم بدء النشر وحفظ الحالة في التخزين المحلي لـ ${platform}`);
    });

    chrome.storage.local.get([`uploadQueue_${platform}`], (result) => {
        if (result[`uploadQueue_${platform}`] && Array.isArray(result[`uploadQueue_${platform}`]) && result[`uploadQueue_${platform}`].length > 0) {    
            console.log(`📂 استئناف الرفع للتصاميم المحفوظة لـ ${platform}`);
            uploadQueue[platform] = result[`uploadQueue_${platform}`];
            uploadQueue[platform].forEach(d => {
                if (!d.imageBase64) {
                    console.warn(`⚠️ لم يتم العثور على imageBase64 داخل ${d.filename} عند الاستئناف.`);
                }
            });
            
            chrome.storage.local.get([`currentlyUploading_${platform}`], (result) => {
                let current = result[`currentlyUploading_${platform}`];
            
                if (current) {
                    let design = uploadQueue[platform].find(d => d.filename === current);
            
                    // ✅ إذا التصميم موجود ولكن الصورة غير صالحة نحذفه وننتقل للي بعده
                    if (!design || !design.imageBase64 || !design.imageBase64.includes(",")) {
                        console.warn(`⚠️ الصورة غير جاهزة بعد للتصميم ${current}, سيتم إعادة المحاولة بعد 5 ثواني...`);
                        
                        setTimeout(() => {
                            startUploading(platform); // إعادة تشغيل الرفع دون حذف
                        }, 5000);
                    
                        return; // لا تحذف التصميم ولا تنتقل للي بعده
                    }
                    
                    console.log(`🔁 استئناف رفع التصميم المتوقف: ${current}`);
                    openUploadPage(platform, design);
            
                } else {
                    processNextUpload(platform);
                }
            });
            
            
        } else {
            console.log(`🌐 لم يتم العثور على تصاميم محفوظة، سيتم طلب البيانات من السيرفر.`);
            fetch(`http://127.0.0.1:5000/get-data?platform=${platform}`)
            .then(response => response.json())
            .then(data => {
                if (!data || data.error) {
                    console.error(`🚨 خطأ في جلب البيانات من السيرفر: ${data?.error || "غير معروف"}`);
                    isRunning[platform] = false;
                    return;
                }

                totalDesigns[platform] = data.designs.length;
                uploadQueue[platform] = data.designs;
                chrome.storage.local.set({ [`uploaded_${platform}`]: 0 });

                chrome.storage.local.set({ [`uploadQueue_${platform}`]: uploadQueue[platform] }, () => {
                    console.log(`✅ تم تخزين جميع التصاميم لـ ${platform} في التخزين المحلي.`);
                });

                console.log(`✅ تم استلام ${uploadQueue[platform].length} تصاميم من السيرفر، جاري تنزيل الصور...`);
                downloadAllImages(platform).then(() => {
                    fetch(`http://127.0.0.1:5000/clear-data`, {
                        method: "POST",
                        headers: { "Content-Type": "application/json" },
                        body: JSON.stringify({ platform: platform })
                    }).then(() => {
                        console.log(`🗑️ تم حذف بيانات ${platform} من السيرفر بعد تخزين الصور.`);
                    });

                    processNextUpload(platform);
                });
            })
            .catch((error) => {
                console.error(`❌ فشل في الاتصال بالسيرفر: ${error.message}`);
                isRunning[platform] = false;
            });
        }
    });
}


function startRadar(tabId, platform, design) {
    let radarInterval = setInterval(() => {
        if (!isRunning[platform]) {
            clearInterval(radarInterval);
            return;
        }

        chrome.scripting.executeScript({
            target: { tabId: tabId },
            func: () => {
                const message = document.querySelector(".site-notification__message")?.innerText || "";
                const error = document.querySelector("div.error")?.innerText || "";
            
                const isRedbubble = location.hostname.includes("redbubble.com");
                const isTeePublic = location.hostname.includes("teepublic.com");
            
                const uploadReady = isRedbubble
                    ? document.querySelector("input#select-image-base") !== null
                    : document.querySelector(".m-uploader__dropzone-clickable") !== null;
            
                return {
                    limitReached: message.includes("You have reached your daily limit"),
                    notLoggedIn: error.includes("You must be logged in"),
                    uploadReady: uploadReady
                };
            }
            
        }, (results) => {
            if (!results || !results[0]) return;
            const { limitReached, notLoggedIn, uploadReady } = results[0].result;

            if (limitReached) {
                console.warn("🚫 الحد اليومي تم الوصول إليه!");
                isRunning[platform] = false;
                clearInterval(radarInterval);

                chrome.storage.local.set({ [`isRunning_${platform}`]: false });
                chrome.notifications.create({
                    type: "basic",
                    iconUrl: "icon16.png",
                    title: "TeePublic Limit Reached",
                    message: "You reached the 25 uploads per day limit."
                });
                return;
            }

            if (notLoggedIn) {
                console.warn("🚫 لم يتم تسجيل الدخول!");
                isRunning[platform] = false;
                clearInterval(radarInterval);

                chrome.storage.local.set({ [`isRunning_${platform}`]: false });
                chrome.notifications.create({
                    type: "basic",
                    iconUrl: "icon16.png",
                    title: "Not Logged In",
                    message: "You must be logged in to continue uploading."
                });
                return;
            }

            if (uploadReady) {
                console.log("✅ مربع الرفع جاهز. جاري إرسال التصميم...");
                clearInterval(radarInterval);
                sendDesignToContentScript(platform, design, tabId);
            }
        });
    }, 1000);
}


// ✅ إيقاف عملية النشر
function stopUploading(platform) {
    isRunning[platform] = false;

    // ✅ احذف التصميم الجاري رفعه من التخزين حتى لا يتم تعليقه عند إعادة التشغيل
    chrome.storage.local.remove([`currentlyUploading_${platform}`], () => {
        chrome.storage.local.set({ [`isRunning_${platform}`]: false }, () => {
            console.log(`⏸️ تم إيقاف الرفع وحفظ الحالة في التخزين المحلي لـ ${platform}`);
        });
    });

    chrome.tabs.query({}, (tabs) => {
        tabs.forEach(tab => {
            let matchRedbubble = tab.url.includes("redbubble.com") && (tab.url.includes("/portfolio") || tab.url.includes("/studio") || tab.url.includes("/images/"));
            let matchTeePublic = tab.url.includes("teepublic.com/design");

            if (platform === "TeePublic" && matchTeePublic) {
                chrome.tabs.sendMessage(tab.id, { action: "stopUpload" }, () => {
                    if (chrome.runtime.lastError) {
                        console.warn("⚠️ فشل إرسال الرسالة لـ TeePublic:", chrome.runtime.lastError.message);
                    } else {
                        setTimeout(() => {
                            chrome.tabs.remove(tab.id, () => {
                                if (chrome.runtime.lastError) {
                                    console.warn("⚠️ فشل إغلاق تبويب TeePublic:", chrome.runtime.lastError.message);
                                }
                            });
                        }, 1000);
                    }
                });
            }

            if (platform === "Redbubble" && matchRedbubble) {
                chrome.tabs.sendMessage(tab.id, { action: "stopUpload" }, () => {
                    if (chrome.runtime.lastError) {
                        console.warn("⚠️ فشل إرسال الرسالة لـ Redbubble:", chrome.runtime.lastError.message);
                    } else {
                        setTimeout(() => {
                            chrome.tabs.remove(tab.id, () => {
                                if (chrome.runtime.lastError) {
                                    console.warn("⚠️ فشل إغلاق تبويب Redbubble:", chrome.runtime.lastError.message);
                                }
                            });
                        }, 1000);
                    }
                });
            }
        });
    });
}


// ✅ تنزيل جميع الصور وتخزينها محليًا
function downloadAllImages(platform) {
    return new Promise((resolve, reject) => { // ✅ تأكد أن الدالة تُرجع Promise
        let downloadPromises = uploadQueue[platform].map(design => {
            return new Promise((resolve, reject) => {
                console.log(`📥 تحميل الصورة: ${design.image_url}`);

                fetch(`${design.image_url}?t=${new Date().getTime()}`, { cache: "no-store" })
                    .then(response => {
                        if (!response.ok) {
                            throw new Error(`❌ HTTP Error: ${response.status} - ${design.image_url}`);
                        }
                        return response.blob();
                    })
                    .then(blob => {
                        let reader = new FileReader();
                        reader.onloadend = () => {
                            design.imageBase64 = reader.result;
                            console.log(`✅ تم تحميل الصورة بنجاح: ${design.filename}`);
                            resolve();
                        };
                        reader.readAsDataURL(blob);
                    })
                    .catch(error => {
                        console.error(`🚨 فشل تحميل الصورة: ${design.image_url} - السبب: ${error.message}`);
                        reject(error);
                    });
            });
        });

        Promise.allSettled(downloadPromises).then(results => {
            let failedDownloads = results.filter(result => result.status === "rejected");
            let successfulDownloads = results.filter(result => result.status === "fulfilled");

            console.log(`🔍 تحميل الصور: ${successfulDownloads.length} ناجحة / ${failedDownloads.length} فشلت`);

            if (failedDownloads.length > 0) {
                console.error(`❌ ${failedDownloads.length} صور فشلت في التحميل، سيتم إعادة المحاولة بعد 5 ثواني...`);
                setTimeout(() => downloadAllImages(platform).then(resolve).catch(reject), 5000);
            } else {
                console.log(`✅ جميع الصور تم تحميلها بنجاح!`);
                resolve(); // ✅ حل المشكلة: إرجاع نجاح عند اكتمال التحميل
            }
        });
    });
}


// ✅ إرسال التصميم التالي
function processNextUpload(platform) {
    if (!isRunning[platform] || uploadQueue[platform].length === 0) {
        isRunning[platform] = false;
        sendCompletionNotification(platform);
        return;
    }

    let design = uploadQueue[platform][0]; // 🔥 دائمًا نأخذ أول تصميم في القائمة
    openUploadPage(platform, design);
}


// ✅ فتح صفحة TeePublic أو Redbubble
function openUploadPage(platform, design) {
    let url = platform === "TeePublic"
    ? "https://www.teepublic.com/design/quick_create?auto=1"
    : `${design.copy_link}?auto=1`;

    chrome.tabs.create({ url }, (tab) => {
        let tabId = tab.id;  // ✅ تأكد من الحصول على tabId
        console.log(`🔄 تم فتح علامة تبويب جديدة: ${tabId}`);

        setTimeout(() => {
            console.log(`⏳ إرسال التصميم الأول...`);
            startRadar(tabId, platform, design);
            monitorTabForPublishing(tabId, platform, design.filename);
        }, 5000);        
    });
}


// ✅ مراقبة رابط التبويب لمعرفة متى يتم نشر التصميم
function monitorTabForPublishing(tabId, platform, filename) {
    let checkInterval = setInterval(() => {
        // ✅ التحقق مما إذا كان الإيقاف قد تم
        if (!isRunning[platform]) {
            console.log(`⏹️ تم إيقاف المراقبة لـ ${platform}.`);
            clearInterval(checkInterval);
            return;
        }

        chrome.tabs.get(tabId, (tab) => {
            if (chrome.runtime.lastError || !tab || !tab.url) {
                clearInterval(checkInterval);
                return;
            }

            console.log(`🔍 Checking current URL: ${tab.url}`);
            
            let isPublished = false;

            // ✅ التحقق من نشر التصميم في TeePublic
            if (platform === "TeePublic" && tab.url.includes("/t-shirt/")) {
                console.log(`✅ Design published on TeePublic: ${filename}`);
                isPublished = true;
            }

            // ✅ التحقق من نشر التصميم في Redbubble
            if (platform === "Redbubble" && (tab.url.includes("/shop/ap/") || tab.url.includes("/studio/promote/"))) {
                console.log(`✅ Design published on Redbubble: ${filename}`);
                isPublished = true;
            }

            if (isPublished) {
                uploadQueue[platform] = uploadQueue[platform].filter(design => design.filename !== filename);

                chrome.storage.local.set({ [`uploadQueue_${platform}`]: uploadQueue[platform] }, () => {
                    console.log(`✅ تم تحديث التخزين المحلي بعد حذف التصميم.`);
                });

                chrome.storage.local.get([`uploaded_${platform}`], (result) => {
                    let uploadedCount = result[`uploaded_${platform}`] || 0;
                    uploadedCount += 1;
                    chrome.storage.local.set({ [`uploaded_${platform}`]: uploadedCount });

                    chrome.runtime.sendMessage({ action: "updateCounter", platform: platform, uploaded: uploadedCount });
                });

                if (uploadQueue[platform].length === 0 || !isRunning[platform]) {
                    console.log(`✅ جميع التصاميم لـ ${platform} تم نشرها أو تم إيقاف العملية.`);
                    isRunning[platform] = false;
                    chrome.storage.local.set({ [`isRunning_${platform}`]: false });
                    clearInterval(checkInterval);
                    return;
                }

                console.log(`🔄 تحميل التصميم التالي...`);
                let nextDesign = uploadQueue[platform][0];
                let newURL = platform === "TeePublic" ? "https://www.teepublic.com/design/quick_create" : nextDesign.copy_link;

                chrome.tabs.update(tabId, { url: newURL }, () => {
                    console.log(`🔄 تم تحديث الرابط إلى: ${newURL}`);

                    setTimeout(() => {
                        if (!isRunning[platform]) {
                            console.log(`⏹️ تم إيقاف العملية قبل إرسال التصميم التالي.`);
                            clearInterval(checkInterval);
                            return;
                        }

                        console.log(`⏳ إرسال التصميم التالي...`);
                        sendDesignToContentScript(platform, nextDesign, tabId);
                        monitorTabForPublishing(tabId, platform, nextDesign.filename);
                    }, 3000);
                });

                clearInterval(checkInterval);
            }
        });
    }, 2000);
}


// ✅ انتظار ظهور زر رفع التصميم قبل إرسال التصميم التالي
function waitForUploadField(tabId, platform, design) {
    let retryCount = 0;
    let maxRetries = 60; // 60 محاولة = دقيقة واحدة

    let checkUploadField = setInterval(() => {
        if (!isRunning[platform]) {
            clearInterval(checkUploadField);
            return;
        }

        chrome.scripting.executeScript({
            target: { tabId: tabId },
            func: () => {
                return document.querySelector(".m-uploader__dropzone-clickable") !== null;
            }
        }, (results) => {
            if (chrome.runtime.lastError || !results || !results[0]) return;

            if (results[0].result === true) {
                console.log(`✅ زر رفع الصور ظهر، سيتم الآن إرسال التصميم.`);
                clearInterval(checkUploadField);

                setTimeout(() => {
                    sendDesignToContentScript(platform, design, tabId);
                }, 1000);
            } else {
                retryCount++;

                if (retryCount >= maxRetries) {
                    console.warn(`⏳ لم يظهر مربع الرفع خلال دقيقة، سيتم إعادة تحميل نفس الصفحة...`);
                    retryCount = 0;

                    chrome.tabs.get(tabId, (tab) => {
                        if (tab && tab.url) {
                            chrome.tabs.update(tabId, { url: tab.url }, () => {
                                console.log(`🔁 تم تحديث نفس الرابط (${tab.url}) لإعادة المحاولة.`);
                            });
                        }
                    });
                }
            }
        });
    }, 1000);
}


function sendDesignToContentScript(platform, design, tabId) {
    let scriptFile = platform === "TeePublic" ? "content_teepublic.js" : "content_redbubble.js";

    chrome.tabs.get(tabId, (tab) => {
        if (chrome.runtime.lastError || !tab) {
            console.error("🚨 التبويب غير موجود أو مغلق!");
            return;
        }

        chrome.scripting.executeScript({
            target: { tabId: tabId },
            files: [scriptFile]
        }).then(() => {
            console.log(`✅ تم تحميل سكربت ${scriptFile} بنجاح`);

            let messageData = {
                action: "uploadDesign",
                title: design.title,
                description: design.description,
                imageBase64: design.imageBase64,
                filename: design.filename,
            };

            if (platform === "Redbubble") {
                messageData.tags = design.tags;
                messageData.copy_link = design.copy_link;
            } else {
                messageData.primary_tag = design.primary_tag;
                messageData.supporting_tags = design.supporting_tags;
                messageData.colors = design.colors;
                messageData.products = design.products;
                messageData.mature_content = design.mature_content;
            }

            console.log("🚀 انتظار 3 ثواني قبل إرسال التصميم...");
            chrome.storage.local.set({ [`currentlyUploading_${platform}`]: design.filename });
            setTimeout(() => {
                if (!design.imageBase64 || typeof design.imageBase64 !== 'string' || !design.imageBase64.includes(",")) {
                    console.warn(`⚠️ الصورة غير جاهزة للتصميم ${design.filename}, سيتم إعادة المحاولة بعد 2 ثانية...`);
                    setTimeout(() => {
                        startRadar(tabId, platform, design);
                    }, 2000);
                    return;
                }
                
                chrome.tabs.sendMessage(tabId, messageData, (response) => {
                
                    if (chrome.runtime.lastError) {
                    } else if (response && response.status === "published") {
                        console.log("✅ تم نشر التصميم بنجاح:", response.filename);
                        handleDesignPublished(platform, response.filename, tabId);
                    } else {
                    }
                });
            }, 2000);
        }).catch(error => {
            console.error("🚨 فشل تحميل سكريبت content_teepublic.js", error);
        });
    });
}


// ✅ عند استلام إشارة بأن التصميم تم نشره، حذف التصميم، إغلاق التبويب، وإرسال التالي
function handleDesignPublished(platform, filename, tabId) {
    console.log(`📩 استلام رسالة: تم نشر التصميم (${filename}) في ${platform}.`);

    // ✅ حذف التصميم المنشور من قائمة الانتظار
    uploadQueue[platform] = uploadQueue[platform].filter(design => design.filename !== filename);

    // ✅ تحديث التخزين المحلي بعد حذف التصميم
    chrome.storage.local.set({ [`uploadQueue_${platform}`]: uploadQueue[platform] }, () => {
        console.log(`✅ تم تخزين جميع التصاميم مع الصور لـ ${platform} في التخزين المحلي.`);
    });
    

    chrome.storage.local.remove([`currentlyUploading_${platform}`]);
    console.log(`🗑️ تم حذف التصميم: ${filename}`);

    // ✅ تحديث عدد التصاميم المنشورة في التخزين المحلي
    chrome.storage.local.get([`uploaded_${platform}`], (result) => {
        let uploadedCount = result[`uploaded_${platform}`] || 0;
        uploadedCount += 1; // زيادة العداد عند نشر كل تصميم
        chrome.storage.local.set({ [`uploaded_${platform}`]: uploadedCount });

        // ✅ إرسال رسالة إلى `popup.js` لتحديث العداد في الواجهة
        chrome.runtime.sendMessage({ action: "updateCounter", platform: platform, uploaded: uploadedCount });
    });


    // ✅ التحقق مما إذا كان هناك تصاميم أخرى
    if (uploadQueue[platform].length === 0) {
        console.log(`✅ جميع التصاميم في ${platform} تم نشرها.`);
        isRunning[platform] = false;
    
        // ✅ حذف التخزين المحلي لأن جميع التصاميم تم رفعها
        chrome.storage.local.remove([`uploadQueue_${platform}`]);
    } else {
        console.log(`🔄 يوجد ${uploadQueue[platform].length} تصاميم متبقية، بدء التصميم التالي...`);
        processNextUpload(platform);
    }
    

    console.log(`🔄 تحميل التصميم التالي...`);

    // ✅ تحديث الرابط في نفس التبويب وإعادة تنفيذ `content_teepublic.js`
    let nextDesign = uploadQueue[platform][0];
    let newURL = platform === "TeePublic" ? "https://www.teepublic.com/design/quick_create" : nextDesign.copy_link;

    chrome.tabs.update(tabId, { url: newURL }, () => {
        console.log(`🔄 تم تغيير الرابط إلى: ${newURL}`);

        setTimeout(() => {
            console.log(`⏳ انتظار ظهور مربع رفع الصور للتصميم التالي...`);
            startRadar(tabId, platform, nextDesign);
        }, 3000);
        
    });
}

// ✅ إرسال إشعار عند انتهاء جميع التصاميم لمنصة معينة
function sendCompletionNotification(platform) {
    chrome.notifications.create({
        type: "basic",
        iconUrl: "icon16.png",
        title: "Upload Completed",
        message: `All designs for ${platform} have been uploaded successfully!`
    });
}

// ✅ مراقبة التبويبات عند الإغلاق
chrome.tabs.onRemoved.addListener((tabId, removeInfo) => {
    chrome.tabs.get(tabId, (tab) => {
        if (chrome.runtime.lastError) return; // التبويب ربما أغلق بالفعل

        const url = tab?.url || "";

        if (url.includes("teepublic.com/design")) {
            console.log("🛑 تم إغلاق تبويب TeePublic أثناء النشر، سيتم إيقاف العملية.");
            forceStopUpload("TeePublic");
        }

        if (url.includes("redbubble.com/studio")) {
            console.log("🛑 تم إغلاق تبويب Redbubble أثناء النشر، سيتم إيقاف العملية.");
            forceStopUpload("Redbubble");
        }
    });
});

function forceStopUpload(platform) {
    isRunning[platform] = false;

    chrome.storage.local.set({ [`isRunning_${platform}`]: false }, () => {
        console.log(`⛔ تم إيقاف النشر تلقائيًا بعد إغلاق التبويب لـ ${platform}`);
    });
}
