document.addEventListener("DOMContentLoaded", function () {
    document.getElementById("main-section").style.display = "block";
    updateCounters("TeePublic");
    updateCounters("Redbubble");
    checkIfRunning("TeePublic");
    checkIfRunning("Redbubble");
    setupButtons("TeePublic");
    setupButtons("Redbubble");
  });
  
document.getElementById("saveLicense")?.addEventListener("click", function () {
    const key = document.getElementById("licenseKey").value.trim();
    if (!key) return;

    const fp = encodeURIComponent(getFingerprint());
fetch(`${LICENSE_API}?key=${key}&fp=${fp}`)
        .then(res => res.json())
        .then(data => {
            if (data.valid) {
                chrome.storage.local.set({ "user_license": key }, () => {
                    location.reload();
                });
            } else {
                alert("❌ " + data.reason);
            }
        });
});


// ✅ الدوال الأصلية بدون أي حذف أو تعديل

function checkIfRunning(platform) {
    chrome.storage.local.get([`isRunning_${platform}`], (result) => {
        let startBtn = document.getElementById(`${platform.toLowerCase()}-start`);
        let stopBtn = document.getElementById(`${platform.toLowerCase()}-stop`);

        if (result[`isRunning_${platform}`]) {
            startBtn.disabled = true;
            stopBtn.disabled = false;
        } else {
            startBtn.disabled = false;
            stopBtn.disabled = true;
        }
    });
}


// ✅ تحديث عدد التصاميم في التخزين
function updateCounters(platform) {
    chrome.storage.local.get([`uploadQueue_${platform}`], function (result) {
        let storedDesigns = result[`uploadQueue_${platform}`] ? result[`uploadQueue_${platform}`].length : 0;
        document.getElementById(`${platform.toLowerCase()}-stored`).innerText = storedDesigns;
    });

    chrome.storage.local.get([`uploaded_${platform}`], function (result) {
        let uploadedDesigns = result[`uploaded_${platform}`] || 0;
        document.getElementById(`${platform.toLowerCase()}-uploaded`).innerText = uploadedDesigns;
    });
}


// ✅ استقبال رسالة تحديث العداد من background.js
chrome.runtime.onMessage.addListener((request, sender, sendResponse) => {
    if (request.action === "updateCounter") {
        document.getElementById(`${request.platform.toLowerCase()}-uploaded`).innerText = request.uploaded;
    }
});


function showTemporaryMessage(message) {
    const msgBox = document.createElement("div");
    msgBox.innerText = message;
    msgBox.style.position = "fixed";
    msgBox.style.bottom = "20px";
    msgBox.style.left = "50%";
    msgBox.style.transform = "translateX(-50%)";
    msgBox.style.background = "#333";
    msgBox.style.color = "#fff";
    msgBox.style.padding = "10px 20px";
    msgBox.style.borderRadius = "8px";
    msgBox.style.zIndex = 9999;
    msgBox.style.fontSize = "14px";
    msgBox.style.boxShadow = "0 2px 6px rgba(0,0,0,0.2)";
    document.body.appendChild(msgBox);

    setTimeout(() => {
        msgBox.remove();
    }, 2500);
}

// ✅ إعداد أزرار التحكم
function setupButtons(platform) {
    let startBtn = document.getElementById(`${platform.toLowerCase()}-start`);
    let stopBtn = document.getElementById(`${platform.toLowerCase()}-stop`);
    let clearBtn = document.getElementById(`${platform.toLowerCase()}-clear`);

    let allowStopWithoutUpload = false; // ✅ متغير جديد للسماح بالإيقاف بعد Clear

    stopBtn.addEventListener("click", function () {
        chrome.storage.local.get([`uploaded_${platform}`], function (result) {
            let uploadedCount = result[`uploaded_${platform}`] || 0;

            if (uploadedCount === 0 && !allowStopWithoutUpload) {
                showTemporaryMessage("⚠️ You can't stop uploading before the first design is published.");
                return;
            }

            chrome.runtime.sendMessage({ action: "stopUploading", platform: platform });
            startBtn.disabled = false;
            stopBtn.disabled = true;
        });
    });

    startBtn.addEventListener("click", function () {
        chrome.storage.local.get([`uploadQueue_${platform}`], function (result) {
            let designs = result[`uploadQueue_${platform}`];

            // ✅ إذا التصاميم موجودة في التخزين المحلي
            if (designs && designs.length > 0) {
                chrome.runtime.sendMessage({ action: "startUploading", platform: platform });
                startBtn.disabled = true;
                stopBtn.disabled = false;
                return;
            }

            // ✅ إذا لم تكن في التخزين المحلي، تحقق من السيرفر
            fetch(`http://127.0.0.1:5000/get-data?platform=${platform}`)
                .then(response => response.json())
                .then(data => {
                    if (!data || data.error || !data.designs || data.designs.length === 0) {
                        showTemporaryMessage("⚠️ No designs found. Please upload your files in the desktop app first.");
                        return;
                    }

                    // ✅ إذا توجد تصاميم في السيرفر، نبدأ النشر
                    chrome.runtime.sendMessage({ action: "startUploading", platform: platform });
                    startBtn.disabled = true;
                    stopBtn.disabled = false;
                })
                .catch((err) => {
                    showTemporaryMessage("❌ Failed to connect to server. Make sure the app is running.");
                    console.error("Fetch error:", err);
                });
        });
    });

    clearBtn.addEventListener("click", function () {
        chrome.storage.local.get([`uploadQueue_${platform}`], function (result) {
            let storedDesigns = result[`uploadQueue_${platform}`];

            if (!storedDesigns || storedDesigns.length === 0) {
                showTemporaryMessage("⚠️ No designs to clear. The queue is already empty.");
                return;
            }

            chrome.storage.local.remove([`uploadQueue_${platform}`], function () {
                document.getElementById(`${platform.toLowerCase()}-stored`).innerText = "0";
                console.log(`🗑️ تم حذف التصاميم المخزنة لـ ${platform}`);

                allowStopWithoutUpload = true; // ✅ السماح بالإيقاف بعد الحذف

                showTemporaryMessage("🗑️ All designs have been cleared. Please upload your files in the app and click 'Start' again to resume.");
            });
        });
    });
}
